@@ -73,10 +73,11 @@ class SignatureTestCase(SimpleTestCase):
     def setUp(self):
         self.auth = SignatureAuthentication()
 
-    def test_no_headers_in_signature(self):
+    def test_no_headers_in_signature_is_date(self):
         signature = build_signature([])
-        self.assertRaises(AuthenticationFailed,
-                          self.auth.get_headers_from_signature, signature)
+        headers = self.auth.get_headers_from_signature(signature)
+        self.assertEqual(1, len(headers))
+        self.assertEqual("date", headers[0])
 
     def test_date_in_signature(self):
         signature = build_signature(['date'])
@@ -152,7 +153,7 @@ class SignatureAuthenticationTestCase(TestCase):
 
         def fetch_user_data(self, api_key):
             if api_key != KEYID:
-                raise AuthenticationFailed('Bad API key')
+                return None
 
             return (self.user, SECRET)
 
@@ -160,8 +161,7 @@ class SignatureAuthenticationTestCase(TestCase):
     TEST_PASSWORD = 'test-password'
 
     def setUp(self):
-        User.objects.create(username=self.TEST_USERNAME)
-        self.test_user = User.objects.get(username=self.TEST_USERNAME)
+        self.test_user = User(username=self.TEST_USERNAME)
         self.test_user.set_password(self.TEST_PASSWORD)
         self.auth = self.APISignatureAuthentication(self.test_user)
 
@@ -203,3 +203,4 @@ class SignatureAuthenticationTestCase(TestCase):
         result = self.auth.authenticate(request)
         self.assertIsNotNone(result)
         self.assertEqual(result[0], self.test_user)
+        self.assertEqual(result[1], KEYID)
